@@ -1,6 +1,6 @@
 package Getopt::EX::Hashed;
 
-our $VERSION = '0.9921';
+our $VERSION = '0.9922';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Getopt::EX::Hashed - Hash store object automation for Getopt::Long
 
 =head1 VERSION
 
-Version 0.9921
+Version 0.9922
 
 =head1 SYNOPSIS
 
@@ -62,7 +62,7 @@ my %DefaultConfig = (
     REMOVE_UNDERSCORE  => 0,
     GETOPT             => 'GetOptions',
     ACCESSOR_PREFIX    => '',
-    DEFAULT            => undef,
+    DEFAULT            => [],
     INVALID_MSG        => \&_invalid_msg,
     );
 lock_keys %DefaultConfig;
@@ -93,6 +93,10 @@ sub configure {
 	}
     };
     while (my($key, $value) = splice @_, 0, 2) {
+	if ($key eq 'DEFAULT') {
+	    ref($value) eq 'ARRAY' or die "DEFAULT must be arrayref";
+	    @$value % 2 == 0       or die "DEFAULT have wrong member";
+	}
 	$config->{$key} = $value;
     }
     return $class;
@@ -121,20 +125,14 @@ sub has {
     my $member = __Member__($caller);
     for my $name (@name) {
 	my $append = $name =~ s/^\+//;
-	my $i = first { $member->[$_]->[0] eq $name } 0 .. $#{$member};
+	my $i = first { $member->[$_][0] eq $name } 0 .. $#{$member};
 	if ($append) {
 	    defined $i or die "$name: Not found\n";
 	    push @{$member->[$i]}, @param;
 	} else {
 	    defined $i and die "$name: Duplicated\n";
 	    my $config = __Config__($caller);
-	    if (exists $config->{DEFAULT} and
-		my $default = $config->{DEFAULT}) {
-		if (ref $default eq 'ARRAY') {
-		    unshift @param, @$default;
-		}
-	    }
-	    push @$member, [ $name, @param ];
+	    push @$member, [ $name, @{$config->{DEFAULT}}, @param ];
 	}
     }
 }
@@ -268,11 +266,10 @@ sub _opt_dest {
 my %tester = (
     min  => sub { $_[-1] >= $_->{min} },
     max  => sub { $_[-1] <= $_->{max} },
-    re   => sub { $_[-1] =~ $_->{re} },
     must => sub {
 	my $must = $_->{must};
 	for $_ (ref($must) eq 'ARRAY' ? @$must : $must) {
-	    &$_ or return 0;
+	    return 0 if not &$_;
 	}
 	return 1;
     },
@@ -280,11 +277,11 @@ my %tester = (
 	my $any = $_->{any};
 	for (ref($any) eq 'ARRAY' ? @$any : $any) {
 	    if (ref eq 'Regexp') {
-		$_[-1] =~ $_ and return 1;
+		return 1 if $_[-1] =~ $_;
 	    } elsif (ref eq 'CODE') {
-		&$_ and return 1;
+		return 1 if &$_;
 	    } else {
-		$_[-1] eq $_ and return 1;
+		return 1 if $_[-1] eq $_;
 	    }
 	}
 	return 0;
@@ -302,7 +299,7 @@ sub _validator {
     sub {
 	local $_ = $m;
 	for my $test (@test) {
-	    &$test or return 0;
+	    return 0 if not &$test;
 	}
 	return 1;
     }
@@ -490,13 +487,6 @@ case insensitive.
     has question => '=s',
         any => qr/^(life|universe|everything)$/i;
 
-=item B<re> => qr/I<regex>/
-
-This parameter will be deprecated soon, because B<any> works same.
-Don't use.
-
-Set the required regular expression pattern for the argument.
-
 =back
 
 =head1 METHOD
